package com.sibatel.solarapp.data

import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import com.sibatel.solarapp.data.model.mobil.Mobil
import com.sibatel.solarapp.data.model.solar.pengambilansolar.PengambilanSolar
import com.sibatel.solarapp.data.model.solar.penggunaansolar.PenggunaanSolar
import com.sibatel.solarapp.data.model.tower.Maintenance
import com.sibatel.solarapp.data.model.user.User

class SolarRepository  private constructor(private val remoteDataSource: RemoteDataSource): SolarDataSource{
    companion object{
        private var instance : SolarRepository? = null

        fun getInstance(remoteDataSource: RemoteDataSource): SolarRepository =
            instance ?: synchronized(this){
                instance ?: SolarRepository(remoteDataSource).apply { instance = this }
            }
    }

    override fun getMobilList(): LiveData<ArrayList<Mobil>> {
        val listMobile = MutableLiveData<ArrayList<Mobil>>()
        remoteDataSource.getMobilData(object : RemoteDataSource.loadDataMobilListCallback{
            override fun onLoadMobil(response: ArrayList<Mobil>?) {
                val mobilList = ArrayList<Mobil>()
                    if (response!=null){
                        for (mobilResponse in response){
                            val mobil = Mobil(
                                nama = mobilResponse.nama,
                                id = mobilResponse.id,
                                jenis = mobilResponse.jenis,
                                status = mobilResponse.status,
                                createdAt = mobilResponse.createdAt,
                                updatedAt = mobilResponse.updatedAt,
                                namaUser = mobilResponse.namaUser,
                                tujuanSite = mobilResponse.tujuanSite,
                                role = mobilResponse.role,
                                tujuanPengambilan = mobilResponse.tujuanPengambilan
                            )
                                mobilList.add(mobil)
                        }
                        listMobile.postValue(mobilList)
                    }
            }

        })
        return listMobile
    }

    override fun getUserList(): LiveData<ArrayList<User>> {
        val listUser = MutableLiveData<ArrayList<User>>()
        remoteDataSource.getUserData(object : RemoteDataSource.loadDataUserListCallback{
            override fun onLoadUser(response: ArrayList<User>?) {
                val userList = ArrayList<User>()
                if (response != null){
                    for (userResponse in response){
                        val user = User(
                            nama = userResponse.nama,
                            cluster = userResponse.cluster,
                            role = userResponse.role,
                            noHp = userResponse.noHp,
                            id = userResponse.id
                        )
                        userList.add(user)
                    }
                    listUser.postValue(userList)
                }
            }

        })
        return listUser
    }

    override fun getPengambilanSolarList(id:Int): LiveData<ArrayList<PengambilanSolar>> {
        val listPengambilanSolar = MutableLiveData<ArrayList<PengambilanSolar>>()
        remoteDataSource.getPengambilanSolarData(id, object : RemoteDataSource.loadDataPengambilanSolarCallback{
            override fun onLoadPengambilanSolar(response: ArrayList<PengambilanSolar>?) {
                val pengambilanList = ArrayList<PengambilanSolar>()
                if (response != null){
                    for (pengambilanResponse in response){
                        val pengambilanaSolar = PengambilanSolar(
                            jlhPendonorSblm = pengambilanResponse.jlhPendonorSblm,
                            gbrGsSblm = pengambilanResponse.gbrGsSblm,
                            dariSite = pengambilanResponse.dariSite,
                            jlhPendonorSdh = pengambilanResponse.jlhPendonorSdh,
                            jlhSlrGsSblm = pengambilanResponse.jlhSlrGsSblm,
                            createdAt = pengambilanResponse.createdAt,
                            gbrSpSblm = pengambilanResponse.gbrSpSblm,
                            jlhSolarDiambil = pengambilanResponse.jlhSolarDiambil,
                            saksi = pengambilanResponse.saksi,
                            jenisGenset = pengambilanResponse.jenisGenset,
                            gbrSpSdh = pengambilanResponse.gbrSpSdh,
                            updatedAt = pengambilanResponse.updatedAt,
                            gbrGsSdh = pengambilanResponse.gbrGsSdh,
                            userId = pengambilanResponse.userId,
                            tanggal = pengambilanResponse.tanggal,
                            id = pengambilanResponse.id,
                            tujuanSite = pengambilanResponse.tujuanSite,
                            jlhSlrGsSdh = pengambilanResponse.jlhSlrGsSdh
                        )
                        pengambilanList.add(pengambilanaSolar)
                    }
                    listPengambilanSolar.postValue(pengambilanList)
                }
            }

        })
        return listPengambilanSolar
    }

    override fun getPenggunaanSolarList(id: Int): LiveData<ArrayList<PenggunaanSolar>> {
        val listPenggunaanSolar = MutableLiveData<ArrayList<PenggunaanSolar>>()
        remoteDataSource.getPenggunaanSolarData(id,object : RemoteDataSource.loadDataPenggunaanSolarCallback{
            override fun onLoadPenggunaanSolar(response: ArrayList<PenggunaanSolar>?) {
                val penggunaanSolarList = ArrayList<PenggunaanSolar>()
                if (response != null){
                    for(penggunaanResponse in response){
                        val penggunaanSolar = PenggunaanSolar(
                            jenisGenset = penggunaanResponse.jenisGenset,
                            updatedAt = penggunaanResponse.updatedAt,
                            userId = penggunaanResponse.userId,
                            totalHm = penggunaanResponse.totalHm,
                            totalLiter = penggunaanResponse.totalLiter,
                            gmbrHmakhir = penggunaanResponse.gmbrHmakhir,
                            createdAt = penggunaanResponse.createdAt,
                            id = penggunaanResponse.id,
                            tanggal = penggunaanResponse.tanggal,
                            hmAwal = penggunaanResponse.hmAwal,
                            hmAkhir = penggunaanResponse.hmAkhir,
                            tujuanSite = penggunaanResponse.tujuanSite,
                            status = penggunaanResponse.status
                        )
                        penggunaanSolarList.add(penggunaanSolar)
                    }
                    listPenggunaanSolar.postValue(penggunaanSolarList)
                }
            }

        })
        return listPenggunaanSolar
    }

    override fun getMaintenanceList(id: Int): LiveData<ArrayList<Maintenance>> {
        val listMaintenance = MutableLiveData<ArrayList<Maintenance>>()
        remoteDataSource.getMaintenanceData(id, object : RemoteDataSource.loadDataMaintenanceCallback{
            override fun onLoadMaintenance(response: ArrayList<Maintenance>?) {
                val maintenanceList = ArrayList<Maintenance>()
                if (response != null){
                    for (maintenanceResponse in response){
                        val maintenance = Maintenance(
                            tanggal = maintenanceResponse.tanggal,
                            tujuanSite =  maintenanceResponse.tujuanSite
                        )
                        maintenanceList.add(maintenance)
                    }
                    listMaintenance.postValue(maintenanceList)
                }

            }

        })
        return listMaintenance
    }


}
