package com.sibatel.solarapp.ui.mentoring

import android.content.Intent
import android.os.Bundle
import android.view.Menu
import android.view.MenuItem
import android.view.View
import androidx.annotation.StringRes
import androidx.appcompat.app.AppCompatActivity
import com.google.android.material.tabs.TabLayoutMediator
import com.sibatel.solarapp.R
import com.sibatel.solarapp.databinding.ActivityMentoringSolarBinding
import com.sibatel.solarapp.ui.LoginActivity
import com.sibatel.solarapp.ui.user.Profil
import com.sibatel.solarapp.utils.SharedPref

class MentoringSolar : AppCompatActivity() {
    private lateinit var binding: ActivityMentoringSolarBinding
    private lateinit var sharedPref: SharedPref

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivityMentoringSolarBinding.inflate(layoutInflater)
        setContentView(binding.root)
        supportActionBar?.elevation = 0f
        supportActionBar?.setDisplayHomeAsUpEnabled(true)

        sharedPref = SharedPref(this)

        val sectionsPagerAdapter = SectionsPagerAdapter( this, sharedPref.getRole1())
        binding.viewPager.adapter = sectionsPagerAdapter


        val tabLayout = binding.tabs


        TabLayoutMediator(tabLayout, binding.viewPager){tab, position ->
            if (sharedPref.getRole1().equals("maintenance"))
                tab.text = "Penggunaan Solar"
            else
                tab.text =  resources.getString(TAB_TITLES[position])
        }.attach()

        val toolbar = binding.appLay
        supportActionBar?.title = "Solar"
        supportActionBar?.setDisplayShowHomeEnabled(true)
        supportActionBar?.setDisplayHomeAsUpEnabled(true)

    }

    override fun onSupportNavigateUp():Boolean{
        onBackPressed()
        return true
    }

    override fun onCreateOptionsMenu(menu: Menu): Boolean {
        menuInflater.inflate(R.menu.menu, menu)
        return true
    }

    override fun onOptionsItemSelected(item: MenuItem): Boolean {
        return when (item.itemId) {
            R.id.action_profil -> {
                val intent = Intent(this, Profil::class.java)
                startActivity(intent)
                return true
            }
            R.id.action_logout ->{
                sharedPref.logout()
                val intent = Intent(this, LoginActivity::class.java)
                startActivity(intent)
                finish()
                return true
            }
            else -> super.onOptionsItemSelected(item)
        }
    }

    companion object{
        @StringRes
        private val TAB_TITLES = intArrayOf(R.string.pengambilan_solar, R.string.penggunaan_solar)
    }

}