package com.sibatel.solarapp.ui.mentoring.solar.penggunaan

import android.content.Intent
import android.os.Bundle
import androidx.fragment.app.Fragment
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.Toast
import androidx.lifecycle.Observer
import androidx.lifecycle.ViewModelProvider
import com.google.android.material.floatingactionbutton.FloatingActionButton
import com.sibatel.solarapp.adapter.PenggunaanSolarAdapter
import com.sibatel.solarapp.data.model.solar.penggunaansolar.PenggunaanSolar
import com.sibatel.solarapp.data.viewmodel.PenggunaanSolarViewModel
import com.sibatel.solarapp.databinding.FragmentPenggunaanSolarBinding
import com.sibatel.solarapp.utils.SharedPref
import com.sibatel.solarapp.utils.ViewModelFactory


class PenggunaanSolarFragment : Fragment() {
    private lateinit var fragmentBinding: FragmentPenggunaanSolarBinding
    private lateinit var sharedPref: SharedPref

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View? {
        fragmentBinding = FragmentPenggunaanSolarBinding.inflate(inflater, container, false)
        return fragmentBinding.root
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        if (activity!=null){

            sharedPref = context?.let { SharedPref(it) }!!

            val fab: FloatingActionButton = fragmentBinding.fab

            fab.setOnClickListener {
                if (sharedPref.getRole1().equals("maintenance")){
                    val intent = Intent(context, PenggunaanSolarMTC::class.java)
                    startActivity(intent)
                }else{
                    val intent = Intent(context, MenuPenggunaanSolar::class.java)
                    startActivity(intent)
                }
                requireActivity().finish()

            }

            val factory = ViewModelFactory.getInstance()
            val viewModelCatalog = ViewModelProvider(
                this, factory
            )[PenggunaanSolarViewModel::class.java]

            showLoading(true)

            viewModelCatalog.getPenggunaanSolar(sharedPref.getId()).observe(viewLifecycleOwner, Observer {
                if (it.isEmpty()){
                    Toast.makeText(context, "Data Kosong", Toast.LENGTH_LONG).show()
                }else{
                    showDataPenggunaanSolar(it)
                }
                showLoading(false)
            })
        }
    }

    private fun showDataPenggunaanSolar(listPenggunaanSolar: ArrayList<PenggunaanSolar>?){
        fragmentBinding.rvMentoringPenggunaan.adapter = PenggunaanSolarAdapter(listPenggunaanSolar)
    }

    private fun showLoading(state: Boolean) {
        if (state)
            fragmentBinding.progress.visibility = View.VISIBLE
        else
            fragmentBinding.progress.visibility = View.GONE
    }
}