package com.sibatel.solarapp.utils

import androidx.lifecycle.ViewModel
import androidx.lifecycle.ViewModelProvider
import com.sibatel.solarapp.data.SolarRepository
import com.sibatel.solarapp.data.viewmodel.*

@Suppress("UNCHECKED_CAST")
class ViewModelFactory private constructor(private val solarRepository: SolarRepository) : ViewModelProvider.NewInstanceFactory() {

    companion object{
        @Volatile
        private var instance: ViewModelFactory? = null

        fun getInstance(): ViewModelFactory =
            instance ?: synchronized(this){
                instance ?: ViewModelFactory(Injection.provideRepository()).apply {
                    instance = this
                }
            }
    }

    override fun <T : ViewModel?> create(modelClass: Class<T>): T {
        return when{
            modelClass.isAssignableFrom(MobilViewModel::class.java) -> {
                MobilViewModel(solarRepository) as T
            }

            modelClass.isAssignableFrom(UserViewModel::class.java)-> {
                UserViewModel(solarRepository) as T
            }

            modelClass.isAssignableFrom(PengambilanSolarViewModel::class.java)-> {
                PengambilanSolarViewModel(solarRepository) as T
            }

            modelClass.isAssignableFrom(PenggunaanSolarViewModel::class.java)->{
                PenggunaanSolarViewModel(solarRepository) as T
            }

            modelClass.isAssignableFrom(MaintenanceViewModel::class.java)->{
                MaintenanceViewModel(solarRepository) as T
            }

            else -> throw IllegalArgumentException("Unknown ViewModel class: " + modelClass.name)
        }
    }
}